<?php
/* --------------------------------------------------------------
   AfterbuyProduct.php 2022-04-14
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2022 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/
declare(strict_types=1);

namespace GXModules\Gambio\Afterbuy\Admin\Classes\AfterbuyXML;

/**
 * Representation of an Afterbuy product.
 *
 * Please note: Naming and capitalization of properties in this class follows the tag names in Afterbuy’s XML API.
 * Do not refactor!
 */
class AfterbuyProduct
{
    /**
     * @var string
     */
    private $EAN;
    
    /**
     * @var string
     */
    private $Name;
    
    /**
     * @var ?string
     */
    private $ManufacturerPartNumber;
    
    /**
     * @var ?string
     */
    private $ShortDescription;
    
    /**
     * @var ?string
     */
    private $Description;
    
    /**
     * @var ?int
     */
    private $Quantity;
    
    /**
     * @var ?float
     */
    private $SellingPrice;
    
    /**
     * @var ?float
     */
    private $TaxRate;
    
    /** @var ?float */
    private $Anr;
    
    /** @var ?int */
    private $ProductID;
    
    public function __construct(string $externalProductId, string $Name)
    {
        $this->EAN  = $externalProductId;
        $this->Name = $Name;
    }
    
    
    public function toArray(): array
    {
        $output        = [
            'EAN'  => $this->EAN,
            'Name' => $this->Name,
        ];
        $supportedTags = [
            'Anr',
            'ProductID',
            'ManufacturerPartNumber',
            'ShortDescription',
            'Description',
            'Quantity',
            'SellingPrice',
            'TaxRate',
        ];
        foreach ($supportedTags as $tag) {
            if (property_exists($this, $tag) && !is_null($this->$tag)) {
                if (is_float($this->$tag)) {
                    $output[$tag] = number_format($this->$tag, 2, ',', '');
                } else {
                    $output[$tag] = $this->$tag;
                }
            }
        }
        
        return $output;
    }
    
    
    /**
     * @return int|null
     */
    public function getProductID(): ?int
    {
        return $this->ProductID;
    }
    
    
    /**
     * @param int|null $ProductID
     */
    public function setProductID(?int $ProductID): void
    {
        $this->ProductID = $ProductID;
    }
    
    
    /**
     * @return float|null
     */
    public function getAnr(): ?float
    {
        return $this->Anr;
    }
    
    
    /**
     * @param float|null $Anr
     */
    public function setAnr(?float $Anr): void
    {
        $this->Anr = $Anr;
    }
    
    
    /**
     * @return string
     */
    public function getEAN(): string
    {
        return $this->EAN;
    }
    
    
    /**
     * @param string $EAN
     */
    public function setEAN(string $EAN): void
    {
        $this->EAN = $EAN;
    }
    
    
    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->Name;
    }
    
    
    /**
     * @param string $Name
     */
    public function setName(string $Name): void
    {
        $this->Name = $Name;
    }
    
    
    /**
     * @return string|null
     */
    public function getManufacturerPartNumber(): ?string
    {
        return $this->ManufacturerPartNumber;
    }
    
    
    /**
     * @param string|null $ManufacturerPartNumber
     */
    public function setManufacturerPartNumber(?string $ManufacturerPartNumber): void
    {
        $this->ManufacturerPartNumber = $ManufacturerPartNumber;
    }
    
    
    /**
     * @return string|null
     */
    public function getShortDescription(): ?string
    {
        return $this->ShortDescription;
    }
    
    
    /**
     * @param string|null $ShortDescription
     */
    public function setShortDescription(?string $ShortDescription): void
    {
        $this->ShortDescription = $ShortDescription;
    }
    
    
    /**
     * @return string|null
     */
    public function getDescription(): ?string
    {
        return $this->Description;
    }
    
    
    /**
     * @param string|null $Description
     */
    public function setDescription(?string $Description): void
    {
        $this->Description = $Description;
    }
    
    
    /**
     * @return int|null
     */
    public function getQuantity(): ?int
    {
        return $this->Quantity;
    }
    
    
    /**
     * @param int|null $Quantity
     */
    public function setQuantity(?int $Quantity): void
    {
        $this->Quantity = $Quantity;
    }
    
    
    /**
     * @return float|null
     */
    public function getSellingPrice(): ?float
    {
        return $this->SellingPrice;
    }
    
    
    /**
     * @param float|null $SellingPrice
     */
    public function setSellingPrice(?float $SellingPrice): void
    {
        $this->SellingPrice = $SellingPrice;
    }
    
    
    /**
     * @return float|null
     */
    public function getTaxRate(): ?float
    {
        return $this->TaxRate;
    }
    
    
    /**
     * @param float|null $TaxRate
     */
    public function setTaxRate(?float $TaxRate): void
    {
        $this->TaxRate = $TaxRate;
    }
    
    
}